@@ -6,7 +6,7 @@
 //! The library is aimed at ease-of-use and performance first.
 //!
 //! ```
-//! use fugit::*;
+//! use fugit::{Duration, ExtU32};
 //!
 //! // Efficient short-hands (`.millis()`, ...)
 //! let d = Duration::<u32, 1, 1_000>::from_ticks(111);
@@ -19,41 +19,43 @@
 //!
 //! // Best effort for fixed types
 //! fn bar(d1: Duration<u32, 1, 1_000>, d2: Duration<u32, 1, 1_000_000>) {
-//!     let sum = d1 + d2;
+//!     let sum = d1 + d2.convert();
 //!     //        ^^^^^^^ Run time move of base, will use a `mul` and `div` instruction (Cortex-M3+) to
-//!     //                perform the move of base
+//!     //                perform the move of base.
+//!     //                The `.convert()` explicitly signals the move of base.
 //!
 //!     let ops = d1 > d2;
 //!     //        ^^^^^^^ Run time comparison of different base, will use 2 `mul` instructions
-//!     //                (Cortex-M3+) to perform the comparison
+//!     //                (Cortex-M3+) to perform the comparison.
 //! }
 //!
 //! fn baz(d1: Duration<u64, 1, 1_000>, d2: Duration<u64, 1, 1_000_000>) {
-//!     let sum = d1 + d2;
+//!     let sum = d1 + d2.convert();
 //!     //        ^^^^^^^ Run time move of base, will use a `mul` insruction and `div`
-//!     //                soft-impl (Cortex-M3+) to perform the move of base
+//!     //                soft-impl (Cortex-M3+) to perform the move of base.
+//!     //                The `.convert()` explicitly signals the move of base.
 //!
 //!     let ops = d1 > d2;
 //!     //        ^^^^^^^ Run time comparison of different base, will use 4 `mul` instructions
-//!     //                (Cortex-M3+) to perform the comparison
+//!     //                (Cortex-M3+) to perform the comparison.
 //! }
 //! ```
 
 #![cfg_attr(not(test), no_std)]
 #![deny(missing_docs)]
 
-pub mod aliases;
+mod aliases;
 mod duration;
 mod helpers;
 mod instant;
 
-pub use duration::{Duration, ExtU32};
+pub use aliases::*;
+pub use duration::{Duration, ExtU32, ExtU64};
 pub use instant::Instant;
 
 #[cfg(test)]
 mod test {
     use crate::Duration;
-    use crate::ExtU32;
     use crate::Instant;
 
     fn take_ms(d: Duration<u32, 1, 1_000>) -> Duration<u32, 1, 1_000> {
@@ -426,6 +428,8 @@ mod test {
 
     #[test]
     fn duration_duration_math_u32() {
+        use crate::ExtU32;
+
         // Same base
         let sum: Duration<u32, 1, 1_000> =
             Duration::<u32, 1, 1_000>::from_ticks(10) + Duration::<u32, 1, 1_000>::from_ticks(1);
@@ -436,12 +440,12 @@ mod test {
         assert_eq!(diff, Duration::<u32, 1, 1_000>::from_ticks(9));
 
         // Different base
-        let sum: Duration<u32, 1, 10_000> =
-            Duration::<u32, 1, 10_000>::from_ticks(10) + Duration::<u32, 1, 1_000>::from_ticks(1);
+        let sum: Duration<u32, 1, 10_000> = Duration::<u32, 1, 10_000>::from_ticks(10)
+            + Duration::<u32, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(sum, Duration::<u32, 1, 1_000>::from_ticks(2));
 
-        let diff: Duration<u32, 1, 10_000> =
-            Duration::<u32, 1, 10_000>::from_ticks(10) - Duration::<u32, 1, 1_000>::from_ticks(1);
+        let diff: Duration<u32, 1, 10_000> = Duration::<u32, 1, 10_000>::from_ticks(10)
+            - Duration::<u32, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(diff, Duration::<u32, 1, 10_000>::from_ticks(0));
 
         // Short hand vs u32 (should not need `.into()`)
@@ -451,6 +455,8 @@ mod test {
 
     #[test]
     fn duration_duration_math_u64() {
+        use crate::ExtU64;
+
         // Same base
         let sum: Duration<u64, 1, 1_000> =
             Duration::<u64, 1, 1_000>::from_ticks(10) + Duration::<u64, 1, 1_000>::from_ticks(1);
@@ -461,12 +467,12 @@ mod test {
         assert_eq!(diff, Duration::<u64, 1, 1_000>::from_ticks(9));
 
         // Different base
-        let sum: Duration<u64, 1, 10_000> =
-            Duration::<u64, 1, 10_000>::from_ticks(10) + Duration::<u64, 1, 1_000>::from_ticks(1);
+        let sum: Duration<u64, 1, 10_000> = Duration::<u64, 1, 10_000>::from_ticks(10)
+            + Duration::<u64, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(sum, Duration::<u64, 1, 1_000>::from_ticks(2));
 
-        let diff: Duration<u64, 1, 10_000> =
-            Duration::<u64, 1, 10_000>::from_ticks(10) - Duration::<u64, 1, 1_000>::from_ticks(1);
+        let diff: Duration<u64, 1, 10_000> = Duration::<u64, 1, 10_000>::from_ticks(10)
+            - Duration::<u64, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(diff, Duration::<u64, 1, 1_000>::from_ticks(0));
 
         // Short hand vs u64 (should not need `.into()`)
@@ -486,52 +492,52 @@ mod test {
         assert_eq!(diff, Duration::<u64, 1, 1_000>::from_ticks(9));
 
         // Different base
-        let sum: Duration<u64, 1, 10_000> =
-            Duration::<u64, 1, 10_000>::from_ticks(10) + Duration::<u32, 1, 1_000>::from_ticks(1);
+        let sum: Duration<u64, 1, 10_000> = Duration::<u64, 1, 10_000>::from_ticks(10)
+            + Duration::<u32, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(sum, Duration::<u64, 1, 1_000>::from_ticks(2));
 
-        let diff: Duration<u64, 1, 10_000> =
-            Duration::<u64, 1, 10_000>::from_ticks(10) - Duration::<u32, 1, 1_000>::from_ticks(1);
+        let diff: Duration<u64, 1, 10_000> = Duration::<u64, 1, 10_000>::from_ticks(10)
+            - Duration::<u32, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(diff, Duration::<u64, 1, 1_000>::from_ticks(0));
     }
 
     #[test]
     fn duration_shorthands_u32() {
-        let z = Duration::<u32, 1, 10_000>::from_ticks(0);
+        use crate::ExtU32;
 
-        let d: Duration<u32, 1, 10_000> = z + 100_000.micros();
+        let d: Duration<u32, 1, 10_000> = 100_000.micros();
         assert_eq!(d.ticks(), 1_000);
 
-        let d: Duration<u32, 1, 10_000> = z + 1.millis();
+        let d: Duration<u32, 1, 10_000> = 1.millis();
         assert_eq!(d.ticks(), 10);
 
-        let d: Duration<u32, 1, 10_000> = z + 1.secs();
+        let d: Duration<u32, 1, 10_000> = 1.secs();
         assert_eq!(d.ticks(), 10_000);
 
-        let d: Duration<u32, 1, 10_000> = z + 1.minutes();
+        let d: Duration<u32, 1, 10_000> = 1.minutes();
         assert_eq!(d.ticks(), 600_000);
 
-        let d: Duration<u32, 1, 10_000> = z + 1.hours();
+        let d: Duration<u32, 1, 10_000> = 1.hours();
         assert_eq!(d.ticks(), 36_000_000);
     }
 
     #[test]
     fn duration_shorthands_u64() {
-        let z = Duration::<u64, 1, 10_000>::from_ticks(0);
+        use crate::ExtU64;
 
-        let d: Duration<u64, 1, 10_000> = z + 100_000.micros();
+        let d: Duration<u64, 1, 10_000> = 100_000.micros();
         assert_eq!(d.ticks(), 1_000);
 
-        let d: Duration<u64, 1, 10_000> = z + 1.millis();
+        let d: Duration<u64, 1, 10_000> = 1.millis();
         assert_eq!(d.ticks(), 10);
 
-        let d: Duration<u64, 1, 10_000> = z + 1.secs();
+        let d: Duration<u64, 1, 10_000> = 1.secs();
         assert_eq!(d.ticks(), 10_000);
 
-        let d: Duration<u64, 1, 10_000> = z + 1.minutes();
+        let d: Duration<u64, 1, 10_000> = 1.minutes();
         assert_eq!(d.ticks(), 600_000);
 
-        let d: Duration<u64, 1, 10_000> = z + 1.hours();
+        let d: Duration<u64, 1, 10_000> = 1.hours();
         assert_eq!(d.ticks(), 36_000_000);
     }
 
@@ -641,6 +647,8 @@ mod test {
 
     #[test]
     fn instant_duration_math_u32() {
+        use crate::ExtU32;
+
         // Instant - Instant, Same base
         let diff: Duration<u32, 1, 1_000> =
             Instant::<u32, 1, 1_000>::from_ticks(10) - Instant::<u32, 1, 1_000>::from_ticks(1);
@@ -656,12 +664,12 @@ mod test {
         assert_eq!(diff, Instant::<u32, 1, 1_000>::from_ticks(9));
 
         // Instant - Duration, Different base
-        let sum: Instant<u32, 1, 10_000> =
-            Instant::<u32, 1, 10_000>::from_ticks(10) + Duration::<u32, 1, 1_000>::from_ticks(1);
+        let sum: Instant<u32, 1, 10_000> = Instant::<u32, 1, 10_000>::from_ticks(10)
+            + Duration::<u32, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(sum, Instant::<u32, 1, 10_000>::from_ticks(20));
 
-        let diff: Instant<u32, 1, 10_000> =
-            Instant::<u32, 1, 10_000>::from_ticks(10) - Duration::<u32, 1, 1_000>::from_ticks(1);
+        let diff: Instant<u32, 1, 10_000> = Instant::<u32, 1, 10_000>::from_ticks(10)
+            - Duration::<u32, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(diff, Instant::<u32, 1, 10_000>::from_ticks(0));
 
         // Instant + Extension trait
@@ -675,6 +683,8 @@ mod test {
 
     #[test]
     fn instant_duration_math_u64() {
+        use crate::ExtU64;
+
         // Instant - Instant, Same base
         let diff: Duration<u64, 1, 1_000> =
             Instant::<u64, 1, 1_000>::from_ticks(10) - Instant::<u64, 1, 1_000>::from_ticks(1);
@@ -690,12 +700,12 @@ mod test {
         assert_eq!(diff, Instant::<u64, 1, 1_000>::from_ticks(9));
 
         // Instant - Duration, Different base
-        let sum: Instant<u64, 1, 10_000> =
-            Instant::<u64, 1, 10_000>::from_ticks(10) + Duration::<u64, 1, 1_000>::from_ticks(1);
+        let sum: Instant<u64, 1, 10_000> = Instant::<u64, 1, 10_000>::from_ticks(10)
+            + Duration::<u64, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(sum, Instant::<u64, 1, 10_000>::from_ticks(20));
 
-        let diff: Instant<u64, 1, 10_000> =
-            Instant::<u64, 1, 10_000>::from_ticks(10) - Duration::<u64, 1, 1_000>::from_ticks(1);
+        let diff: Instant<u64, 1, 10_000> = Instant::<u64, 1, 10_000>::from_ticks(10)
+            - Duration::<u64, 1, 1_000>::from_ticks(1).convert();
         assert_eq!(diff, Instant::<u64, 1, 10_000>::from_ticks(0));
 
         // Instant + Extension trait
